==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/fragments/ChannelJourneyFragment.kt <==
package com.hippoagent.fragments

import android.content.Context
import android.net.ConnectivityManager
import android.os.Bundle
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.TextView
import com.hippoagent.R
import com.hippoagent.adapters.ChannelJourneyAdapter
import androidx.recyclerview.widget.DividerItemDecoration
import android.widget.Toast
import com.hippoagent.BuildConfig
import com.hippoagent.model.user_details.CJourney
import com.hippoagent.utils.DateUtils
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import java.util.*
import kotlin.collections.ArrayList


/**
 * Created by gurmail on 2019-09-09.
 * @author gurmail
 */
class ChannelJourneyFragment: androidx.fragment.app.Fragment() {


    var srLayout: androidx.swiperefreshlayout.widget.SwipeRefreshLayout? = null
    var rvAll: androidx.recyclerview.widget.RecyclerView? = null
    var llNoConversation: LinearLayout? = null
    var title: TextView? = null
    var reasions: TextView? = null

    var adapter: ChannelJourneyAdapter? = null
    var array: ArrayList<CJourney> = ArrayList()
    var tempArray: ArrayList<CJourney> = ArrayList()
    var tempSentAtUtc = ""
    private val inputFormat = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'"
    private val outputFormat = "yyyy-MM-dd h:mm a"
    private var journeyType = object : TypeToken<List<CJourney>>() {

    }.type

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        if(arguments != null)
            array = Gson().fromJson(arguments!!.getString("data"), journeyType)
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.conversation_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        srLayout = view.findViewById(R.id.srLayout)
        rvAll = view.findViewById(R.id.rvAll)
        llNoConversation = view.findViewById(R.id.llNoConversation)
        title = view.findViewById(R.id.title)
        reasions = view.findViewById(R.id.reasions)

        srLayout?.isEnabled = false

        adapter = ChannelJourneyAdapter(tempArray)
        rvAll?.layoutManager = androidx.recyclerview.widget.LinearLayoutManager(activity)
        rvAll?.addItemDecoration(androidx.recyclerview.widget.DividerItemDecoration(context, androidx.recyclerview.widget.DividerItemDecoration.HORIZONTAL))
        rvAll?.adapter = adapter

        /*if(HippoConfig.getInstance().getAttributes().isdebugType()) {
            for(a in 0..10) {
                when(a) {
                    0,1,2,3 -> {
                        array.add(CJourney("2019-09-09T01:43:52.000Z", "Visited Page", "https://blog.mindorks.com/mastering-kotlin-coroutines-in-android-step-by-step-guide"))
                    }
                    4,5,6 -> {
                        array.add(CJourney("2019-09-08T06:20:24.000Z", "Visited Page", "https://medium.com/androiddevelopers/coroutines-on-android-part-i-getting-the-background-3e0e54d20bb"))
                    }
                    else -> {
                        array.add(CJourney("2019-09-04T16:54:06.000Z", "Visited Page", "https://codelabs.developers.google.com/codelabs/kotlin-coroutines/#0"))
                    }
                }
            }
        }*/

        parseData(array)

    }

    override fun onAttach(context: Context) {
        super.onAttach(context)

    }

    override fun onDestroy() {
        super.onDestroy()

    }

    override fun onResume() {
        super.onResume()

    }





    private fun parseData(array: ArrayList<CJourney>) {
        tempArray.clear()
        for(i in 0 until array.size) {
            val localDateTime = DateUtils.getInstance().convertToLocal(array[i].date, inputFormat, outputFormat)

            val localDate = localDateTime.split(" ")
            if (!tempSentAtUtc.equals(localDate[0], ignoreCase = true)) {
                val date = DateUtils.getDate(array[i].date)
                tempArray.add(CJourney(true, date))
                tempSentAtUtc = localDate[0]
            }

            val journeyObj = array[i]
            val time = localDate[1]+localDate[2]//DateUtils.getInstance().convertToLocal(journeyObj.date, inputFormat, "h:mm a")
            //val time = DateUtils.getTime(journeyObj.date)
            journeyObj.date = time
            tempArray.add(journeyObj)
        }

        if(tempArray.size>0) {
            adapter?.notifyDataSetChanged()
            llNoConversation?.visibility = View.GONE
        } else {
            llNoConversation?.visibility = View.VISIBLE
            title?.text = "No channel journey available"
            reasions?.text = ""

        }
    }

    fun isNetworkAvailable(): Boolean {
        val cm = activity?.getSystemService(Context.CONNECTIVITY_SERVICE) as ConnectivityManager?
        val networkInfo = cm!!.activeNetworkInfo
        return networkInfo != null && networkInfo.isConnected
    }

    private fun updateData() {
        if(isNetworkAvailable()) {
            /*val commonParams = CommonParams.Builder()
                    .add(Constants.ACCESS_TOKEN, MyApplication.getInstance().userData.accessToken)
                    .add(Constants.USER_ID, conversation?.getUserId())
                    .add(Constants.CHANNEL_ID, conversation?.channelId)
                    .build()
            Logger.apiRequest("api/users/getUserDetails", Gson().toJson(commonParams.map))

            RestClient.getApiInterface().getUserDetails(commonParams.map)
                    .enqueue(object : ResponseResolver<UserDetailsResponse>(activity, true, true) {
                        override fun success(t: UserDetailsResponse?) {

                        }

                        override fun failure(error: APIError?) {

                        }

                    })*/


        } else {
            Toast.makeText(activity, getString(R.string.fugu_unable_to_connect_internet), Toast.LENGTH_SHORT).show()
        }
    }
}

==> hippoagentsdk-0.0.43-sources.jar: com/hippoagent/fragments/ChannelJourneyFragment.kt <==
package com.hippoagent.fragments

import android.content.Context
import android.net.ConnectivityManager
import android.os.Bundle
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.TextView
import com.hippoagent.R
import com.hippoagent.adapters.ChannelJourneyAdapter
import androidx.recyclerview.widget.DividerItemDecoration
import android.widget.Toast
import com.hippoagent.BuildConfig
import com.hippoagent.model.user_details.CJourney
import com.hippoagent.utils.DateUtils
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import com.hippoagent.langs.Restring
import java.util.*
import kotlin.collections.ArrayList


/**
 * Created by gurmail on 2019-09-09.
 * @author gurmail
 */
class ChannelJourneyFragment: androidx.fragment.app.Fragment() {


    var srLayout: androidx.swiperefreshlayout.widget.SwipeRefreshLayout? = null
    var rvAll: androidx.recyclerview.widget.RecyclerView? = null
    var llNoConversation: LinearLayout? = null
    var title: TextView? = null
    var reasions: TextView? = null

    var adapter: ChannelJourneyAdapter? = null
    var array: ArrayList<CJourney> = ArrayList()
    var tempArray: ArrayList<CJourney> = ArrayList()
    var tempSentAtUtc = ""
    private val inputFormat = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'"
    private val outputFormat = "yyyy-MM-dd h:mm a"
    private var journeyType = object : TypeToken<List<CJourney>>() {

    }.type

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        if(arguments != null)
            array = Gson().fromJson(arguments!!.getString("data"), journeyType)
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.conversation_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        srLayout = view.findViewById(R.id.srLayout)
        rvAll = view.findViewById(R.id.rvAll)
        llNoConversation = view.findViewById(R.id.llNoConversation)
        title = view.findViewById(R.id.title)
        reasions = view.findViewById(R.id.reasions)

        srLayout?.isEnabled = false

        adapter = ChannelJourneyAdapter(tempArray)
        rvAll?.layoutManager = androidx.recyclerview.widget.LinearLayoutManager(activity)
        rvAll?.addItemDecoration(androidx.recyclerview.widget.DividerItemDecoration(context, androidx.recyclerview.widget.DividerItemDecoration.HORIZONTAL))
        rvAll?.adapter = adapter

        parseData(array)

    }

    override fun onAttach(context: Context) {
        super.onAttach(context)

    }

    override fun onDestroy() {
        super.onDestroy()

    }

    override fun onResume() {
        super.onResume()

    }





    private fun parseData(array: ArrayList<CJourney>) {
        tempArray.clear()
        for(i in 0 until array.size) {
            val localDateTime = DateUtils.getInstance().convertToLocal(array[i].date, inputFormat, outputFormat)

            val localDate = localDateTime.split(" ")
            if (!tempSentAtUtc.equals(localDate[0], ignoreCase = true)) {
                val date = DateUtils.getDate(array[i].date)
                tempArray.add(CJourney(true, date))
                tempSentAtUtc = localDate[0]
            }

            val journeyObj = array[i]
            val time = localDate[1]+localDate[2]
            journeyObj.date = time
            tempArray.add(journeyObj)
        }

        if(tempArray.size>0) {
            adapter?.notifyDataSetChanged()
            llNoConversation?.visibility = View.GONE
        } else {
            llNoConversation?.visibility = View.VISIBLE
            title?.text = Restring.getString(activity, R.string.hippo_no_channel_journey)
            reasions?.text = ""

        }
    }

    fun isNetworkAvailable(): Boolean {
        val cm = activity?.getSystemService(Context.CONNECTIVITY_SERVICE) as ConnectivityManager?
        val networkInfo = cm!!.activeNetworkInfo
        return networkInfo != null && networkInfo.isConnected
    }

}
